Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(715)

Unified Diff: net/quic/quartc/quartc_stream.h

Issue 2487613002: Landing Recent QUIC changes until 12:43 PM, Nov 5, 2016 UTC+8 (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quartc/quartc_session.cc ('k') | net/quic/quartc/quartc_stream.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quartc/quartc_stream.h
diff --git a/net/quic/quartc/quartc_stream.h b/net/quic/quartc/quartc_stream.h
index eb75b5465fddd6918b6ebc66ad427cf993d88c77..fc091b9e6b1c440e966f88f022ef1a0441eee88e 100644
--- a/net/quic/quartc/quartc_stream.h
+++ b/net/quic/quartc/quartc_stream.h
@@ -6,20 +6,20 @@
#define NET_QUIC_QUARTC_QUARTC_STREAM_H_
#include "net/quic/core/quic_session.h"
-#include "net/quic/core/reliable_quic_stream.h"
+#include "net/quic/core/quic_stream.h"
#include "net/quic/quartc/quartc_stream_interface.h"
namespace net {
-// Implements a QuartcStreamInterface using a ReliableQuicStream.
-class NET_EXPORT_PRIVATE QuartcStream : public ReliableQuicStream,
+// Implements a QuartcStreamInterface using a QuicStream.
+class NET_EXPORT_PRIVATE QuartcStream : public QuicStream,
public QuartcStreamInterface {
public:
QuartcStream(QuicStreamId id, QuicSession* session);
~QuartcStream() override;
- // ReliableQuicStream overrides.
+ // QuicStream overrides.
void OnDataAvailable() override;
void OnClose() override;
« no previous file with comments | « net/quic/quartc/quartc_session.cc ('k') | net/quic/quartc/quartc_stream.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698